// Class: MinnowApp
//
// Author: Alyce Brady
//
// Modified:
//      Your Name       Date    Reason
//
//
// This class is based on the College Board's <code>SimpleDemo2</code>
// and <code>MBSGUI</code> classes, as allowed by the GNU General
// Public License.  <code>SimpleDemo2</code> and <code>MBSGUI</code>
// are classes within the AP(r) CS Marine Biology Simulation
// case study (see www.collegeboard.com/ap/students/compsci).
//
// This class is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation.
//
// This class is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

import java.awt.Color;

/**
 *  Minnow Program:<br>
 *
 *  The <code>MinnowApp</code> class provides a main method that creates
 *  a simulation of three minnows swimming in a small bounded environment.
 *  It also creates a simple graphical user interface with a window in which
 *  to view the environment and buttons to control stepping through the
 *  simulation.
 *
 *  @author Alyce Brady
 *  @version 1 September 2002
 **/

public class MinnowApp
{
    // Specify attributes of the environment.
    private static final int ENV_ROWS = 10;      // rows in environment
    private static final int ENV_COLS = 10;      // columns in environment

    // Specify attributes of the environment display.
    private static final int MAX_WIDTH = 400;
    private static final int MAX_HEIGHT = 400;
    private static final int MIN_CELL_SIZE = 20;
    private static final Color BACKGROUND_COLOR = Color.blue;

    /** Starts the Minnow program.
     *  The String arguments (args) are not used in this application.
     **/
    public static void main(String[] args)
    {
        // Construct an empty environment and several minnows in the context
        // of that environment.
        Environment env = new BoundedEnv(ENV_ROWS, ENV_COLS);
        Minnow minnow1 = new Minnow(env, new Location(2, 2));
        Minnow minnow2 = new Minnow(env, new Location(2, 3));
        Minnow minnow3 = new Minnow(env, new Location(5, 8));

        // Construct a window to display an environment, and specify how to
        // display a minnow in the environment.
        DisplayMap.associate("Minnow", new MinnowDisplay());
        SettableEnvDisplay display =
                  new MinnowGUI("Minnow Program", BACKGROUND_COLOR,
                                MAX_WIDTH, MAX_HEIGHT, MIN_CELL_SIZE);
        display.setEnv(env);
    }
}

