// Class MinnowGUI
//
// Author: Alyce Brady
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

import java.awt.Color;

/**
 *  Minnow Program:<br>
 *
 *    The <code>MinnowGUI</code> class provides a window in which
 *    to run and display the environment in the Minnow program.
 *
 *  @author Alyce Brady (based on code by Julie Zelenski)
 *  @version 1 January 2003
 **/
public class MinnowGUI extends ActiveEnvFrame
{


  // constructors and initialization methods

    /** Creates an uninitialized MinnowGUI.  Provided for subclass
     *  constructors, which should always use this constructor followed by
     *  a call to <code>init</code>.
     **/
    protected MinnowGUI()
    {
        super(null, true, true, true, true, false);
    }

    /** Creates a new MinnowGUI with no menu bar.  Subclasses should
     *  <strong>not</strong> invoke this constructor; they should call
     *  the <code>init</code> method directly from their own constructors.
     *  (The <code>init</code> method uses the Template Method design
     *  pattern, which does not work correctly in superclass constructors.)
     *    @param title           frame title
     *    @param backgroundColor color to paint background of environment
     *    @param viewingWidth    the width of the viewing area
     *    @param viewingHeight   the height of the viewing area
     *    @param minCellSize     minimum environment cell side length
     **/
    public MinnowGUI(String title, Color bgColor,
                          int viewingWidth, int viewingHeight,
                          int minCellSize)
    {
        this();
        init(title, bgColor, viewingWidth, viewingHeight, minCellSize);
        display.makeToolTipsReportObject();
    }


  // redefinition of a method from the SettableEnvDisplay interface

    /** Sets the Environment being displayed.
     *  (Precondition: env is not null.)
     *    @param environment the Environment to display
     **/
    public void setEnv(Environment environment)
    {
        if ( running )
            stop();
        super.setEnv(environment);
        appController = new Simulation(environment, this);
    }

}